@@ -426,8 +426,15 @@ class AssignKafkaSubscriber(AsyncKafkaSubscriber):
         await self.handle_partitions_assignment(topics)
 
     async def commit(self, task: Task, timeout: float = None):
-        # no commits if no consumer group
         if not self.settings.consumer_group:
-            return
+            # no commits if no consumer group, just resume paused TP
+            meta = self._task_meta.pop(task.uuid, None)
+            if not meta:
+                self.logger.error(f"no metadata for given task '{task.task_type} (uuid={task.uuid})'")
+                raise KeyError()
+
+            tp = TopicPartition(meta[0], meta[1])
+            self.consumer.resume(tp)
+            self.logger.debug(f"{tp} resumed")
 
         await super().commit(task, timeout)
